==> lxqt-panel_0.16.1.orig.tar.xz: lxqt-panel-0.16.1/plugin-statusnotifier/translations/statusnotifier_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>StatusNotifierConfiguration</name>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="14"/>
        <source>Status Notifier Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="28"/>
        <location filename="../statusnotifierconfiguration.ui" line="38"/>
        <source>An auto-hiding item will remain visible for this period if it needs attention.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="31"/>
        <source>Attention period:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="41"/>
        <source> minute(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="72"/>
        <source>Change visibility of items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="85"/>
        <source>Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="90"/>
        <source>Visibility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
        <source>Always show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
        <source>Auto-hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
        <source>Always hide</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-panel_1.4.0.orig.tar.xz: lxqt-panel-1.4.0/plugin-statusnotifier/translations/statusnotifier_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>StatusNotifierConfiguration</name>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="14"/>
        <source>Status Notifier Settings</source>
        <translation>Systeemvakinstellingen</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="28"/>
        <location filename="../statusnotifierconfiguration.ui" line="38"/>
        <source>An auto-hiding item will remain visible for this period if it needs attention.</source>
        <translation>Een item dat automatisch wordt verborgen blijft zichtbaar voor deze duur als er een actie benodigd is.</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="31"/>
        <source>Attention period:</source>
        <translation>Actieperiode:</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="41"/>
        <source> minute(s)</source>
        <translation> minu(u)t(en)</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="72"/>
        <source>Change visibility of items</source>
        <translation>Zichtbaarheid van items aanpassen</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="85"/>
        <source>Item</source>
        <translation>Item</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="90"/>
        <source>Visibility</source>
        <translation>Zichtbaarheid</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
        <source>Always show</source>
        <translation>Altijd tonen</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
        <source>Auto-hide</source>
        <translation>Automatisch verbergen</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
        <source>Always hide</source>
        <translation>Altijd verbergen</translation>
    </message>
</context>
</TS>
